"""
Whoopsie - command ``/usr/bin/find /var/crash /var/tmp -path '*.reports-*/whoopsie-report' -print -quit``
=========================================================================================================
"""

from insights.core import CommandParser
from insights.core.plugins import parser
from insights.specs import Specs
import re

WHOOPSIE_RE = re.compile(r'.*.reports-(\d+)-.*/whoopsie-report')


@parser(Specs.woopsie)
class Whoopsie(CommandParser):
    """
    Class for parsing the ``/usr/bin/find /var/crash /var/tmp -path '*.reports-*/whoopsie-report' -print -quit``
    command.

    Attributes:
        uid (string): uid parsed from the file path
        file (string): the line parsed from the command output

    Sample output of this command is::

        /var/crash/.reports-1000-user/whoopsie-report

    Examples:
        >>> type(whoopsie)
        <class 'insights.parsers.whoopsie.Whoopsie'>
        >>> whoopsie.uid
        '1000'
        >>> whoopsie.file
        '/var/crash/.reports-1000-user/whoopsie-report'
    """

    def parse_content(self, content):
        self.uid = None
        self.file = None

        match_whoopsie = WHOOPSIE_RE.search('\n'.join(content))
        if match_whoopsie:
            self.uid = match_whoopsie.group(1)
            self.file = match_whoopsie.group(0)



import doctest
import pytest

from insights.parsers import whoopsie
from insights.parsers.whoopsie import Whoopsie
from insights.tests import context_wrap

BOTH_MATCHED = """
/var/crash/.reports-1000-user/whoopsie-report
""".strip()

NOT_FIND_MATCHED = """
/usr/bin/find: '/var/crash': No such file or directory
/var/tmp/.reports-1000-user/whoopsie-report
""".strip()

BOTH_NOT_FIND = """
/usr/bin/find: '/var/crash': No such file or directory
/usr/bin/find: '/var/tmp': No such file or directory
""".strip()

BOTH_EMPTY = """
"""

TEST_CASES = [
    (BOTH_MATCHED, "1000", "/var/crash/.reports-1000-user/whoopsie-report"),
    (NOT_FIND_MATCHED, "1000", "/var/tmp/.reports-1000-user/whoopsie-report"),
    (BOTH_NOT_FIND, None, None),
    (BOTH_EMPTY, None, None)
]


@pytest.mark.parametrize("output, uid, file", TEST_CASES)
def test_whoopsie(output, uid, file):
    test = Whoopsie(context_wrap(output))
    assert test.uid == uid
    assert test.file == file


def test_doc_examples():
    env = {
        "whoopsie": Whoopsie(context_wrap(BOTH_MATCHED)),
    }
    failed, total = doctest.testmod(whoopsie, globs=env)
    assert failed == 0
